@@ -29,7 +29,7 @@ Dialog::Dialog(QWidget *parent) :
   QString fontFamilyName = oSettings->value("fontfamily", "Nokia Sans SemiBold").toString();
 
 
-  this->setWindowTitle("Edit note");
+  this->setWindowTitle(tr("Edit note"));
 
   ui->teMain->setFrameShadow(QFrame::Sunken);
   ui->teMain->setFrameShape(QFrame::StyledPanel);
