@@ -12,12 +12,31 @@
 
 int main(int argc, char *argv[])
 {
+
+
+
     QCoreApplication::setOrganizationName("Jan Bergmann");
     QCoreApplication::setApplicationName("simplenotewidget");
     QApplication::setGraphicsSystem("native");
 
     QApplication app(argc, argv);
 
+    QString locale = QLocale::system().name();
+    QString sAppDir = QApplication::applicationDirPath();
+    QTranslator translator;
+    QString sTemp = sAppDir + "/simplenotewidget_" + locale + ".qm";
+    QString sFileName  = "simplenotewidget_" + locale + ".qm";
+    QFile f(sTemp);
+     if( f.exists() )
+     {
+         translator.load(sFileName,sAppDir + "/");
+         app.installTranslator(&translator);
+     }
+
+
+
+
+
     MainWindow w;
     QMaemo5HomescreenAdaptor *adaptor = new QMaemo5HomescreenAdaptor(&w);
     adaptor->setSettingsAvailable(true);
